pynrc.multiaccum
================

.. currentmodule:: pynrc

.. autoclass:: multiaccum
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~multiaccum.nd1
      ~multiaccum.nd2
      ~multiaccum.nd3
      ~multiaccum.nf
      ~multiaccum.ngroup
      ~multiaccum.nint
      ~multiaccum.patterns_list
      ~multiaccum.read_mode

   .. rubric:: Methods Summary

   .. autosummary::

      ~multiaccum.to_dict

   .. rubric:: Methods Documentation

   .. automethod:: to_dict
